Dr.Jit: structured vectorization and differentiation on modern processor architectures
======================================================================================

.. only:: not latex

    .. image:: drjit-logo.svg
        :width: 400px
        :align: center

.. toctree::
   :maxdepth: 1
   :caption: Core

   intro
   demo
   building
   → GitHub <https://github.com/mitsuba-renderer/drjit>


.. toctree::
   :maxdepth: 1
   :caption: Optional features

   autodiff
   cuda
   python
   random

.. toctree::
   :maxdepth: 1
   :caption: Advanced optional features

   vcall
   struct
   loops
   custom

